==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/mi-NZ/admin/licenses/message.php <==
<?php

return array(

    'does_not_exist' => 'License does not exist or you do not have permission to view it.',
    'user_does_not_exist' => 'Kāore te Kaiwhakamahi i te tīariari.',
    'asset_does_not_exist' 	=> 'Ko te taonga e ngana ana koe ki te hono atu ki tenei raihana kaore i te.',
    'owner_doesnt_match_asset' => 'Ko te taonga e ngana ana koe ki te hono atu ki tenei raihana ko te pene atu i te tangata i whiriwhiria i roto i te waahanga kua tohaina.',
    'assoc_users'	 => 'Kei te tirohia tenei raihana ki tetahi kaiwhakamahi me te kore e taea te muku. Titirohia te raihana i te tuatahi, ka ngana ki te muku ano.',
    'select_asset_or_person' => 'Me whiriwhiri koe i tetahi rawa, i tetahi kaiwhakamahi ranei, engari ehara i te mea e rua.',
    'not_found' => 'License not found',
    'seats_available' => ':seat_count seats available',


    'create' => array(
        'error'   => 'Kāore i raihana te waihanga, tēnā whakamātau anō.',
        'success' => 'I waihangahia te raihana.'
    ),

    'deletefile' => array(
        'error'   => 'Kāore te kōnae i mukua. Tena ngana ano.',
        'success' => 'Kua mukua te kōnae.',
    ),

    'upload' => array(
        'error'   => 'Ko nga kōnae kāore i tukuna. Tena ngana ano.',
        'success' => 'Ko te (ngā) kōnae i tukuna paihia.',
        'nofiles' => 'Kaore i whiriwhiria e koe tetahi kōnae mo te tukuna, ko te kōnae e ngana ana koe ki te tuku he nui rawa',
        'invalidfiles' => 'Kotahi, nui atu ranei o ou kōnae he nui rawa atu, he waaahi ranei e kore e whakaaetia. Ko nga kōnae e whakaaetia ana he png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, rar, rtf, xml, me te raihana.',
    ),

    'update' => array(
        'error'   => 'Kāore i te whakahouhia te raihana, tēnā whakamātau anō',
        'success' => 'Kua whakahoutia te raihana.'
    ),

    'delete' => array(
        'confirm'   => 'Kei te hiahia koe ki te muku i tenei raihana?',
        'error'   => 'He raruraru kei te whakakore i te raihana. Tena ngana ano.',
        'success' => 'Kua mukua te raihana.'
    ),

    'checkout' => array(
        'error'   => 'I puta he take hei tirotiro i te raihana. Tena ngana ano.',
        'success' => 'I tohua te raihana',
        'not_enough_seats' => 'Not enough license seats available for checkout',
    ),

    'checkin' => array(
        'error'   => 'I kitea he take e tirotirohia ana i roto i te raihana. Tena ngana ano.',
        'success' => 'I tohua te raihana i te angitu'
    ),

);

==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/mi-NZ/admin/licenses/message.php <==
<?php

return array(

    'does_not_exist' => 'License does not exist or you do not have permission to view it.',
    'user_does_not_exist' => 'User does not exist or you do not have permission to view them.',
    'asset_does_not_exist' 	=> 'Ko te taonga e ngana ana koe ki te hono atu ki tenei raihana kaore i te.',
    'owner_doesnt_match_asset' => 'Ko te taonga e ngana ana koe ki te hono atu ki tenei raihana ko te pene atu i te tangata i whiriwhiria i roto i te waahanga kua tohaina.',
    'assoc_users'	 => 'Kei te tirohia tenei raihana ki tetahi kaiwhakamahi me te kore e taea te muku. Titirohia te raihana i te tuatahi, ka ngana ki te muku ano.',
    'select_asset_or_person' => 'Me whiriwhiri koe i tetahi rawa, i tetahi kaiwhakamahi ranei, engari ehara i te mea e rua.',
    'not_found' => 'License not found',
    'seats_available' => ':seat_count seats available',


    'create' => array(
        'error'   => 'Kāore i raihana te waihanga, tēnā whakamātau anō.',
        'success' => 'I waihangahia te raihana.'
    ),

    'deletefile' => array(
        'error'   => 'Kāore te kōnae i mukua. Tena ngana ano.',
        'success' => 'Kua mukua te kōnae.',
    ),

    'upload' => array(
        'error'   => 'Ko nga kōnae kāore i tukuna. Tena ngana ano.',
        'success' => 'Ko te (ngā) kōnae i tukuna paihia.',
        'nofiles' => 'Kaore i whiriwhiria e koe tetahi kōnae mo te tukuna, ko te kōnae e ngana ana koe ki te tuku he nui rawa',
        'invalidfiles' => 'Kotahi, nui atu ranei o ou kōnae he nui rawa atu, he waaahi ranei e kore e whakaaetia. Ko nga kōnae e whakaaetia ana he png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, rar, rtf, xml, me te raihana.',
    ),

    'update' => array(
        'error'   => 'Kāore i te whakahouhia te raihana, tēnā whakamātau anō',
        'success' => 'Kua whakahoutia te raihana.'
    ),

    'delete' => array(
        'confirm'   => 'Kei te hiahia koe ki te muku i tenei raihana?',
        'error'   => 'He raruraru kei te whakakore i te raihana. Tena ngana ano.',
        'success' => 'Kua mukua te raihana.'
    ),

    'checkout' => array(
        'error'   => 'I puta he take hei tirotiro i te raihana. Tena ngana ano.',
        'success' => 'I tohua te raihana',
        'not_enough_seats' => 'Not enough license seats available for checkout',
        'mismatch' => 'The license seat provided does not match the license',
        'unavailable' => 'This seat is not available for checkout.',
    ),

    'checkin' => array(
        'error'   => 'I kitea he take e tirotirohia ana i roto i te raihana. Tena ngana ano.',
        'success' => 'I tohua te raihana i te angitu'
    ),

);
